@@ -538,7 +538,7 @@ class ECMWF_download(object):
                              ("month_start", self.month_start), ("month_end", self.month_end),
                              ("year", self.year)]
                 if steps is not None:
-                    meta_data.append(("steps", np.array(steps, dtype=np.float)))
+                    meta_data.append(("steps", np.array(steps, dtype=float)))
 
                 for name, obj in meta_data:
                     era_h5_file.create_array(era_h5, name=name, obj=obj)
@@ -622,7 +622,7 @@ class ECMWF_download(object):
                              ("month_start", self.month_start), ("month_end", self.month_end),
                              ("year", self.year)]
                 if steps is not None:
-                    meta_data.append(("steps", np.array(steps, dtype=np.float)))
+                    meta_data.append(("steps", np.array(steps, dtype=float)))
 
                 for name, obj in meta_data:
                     era_h5_file.create_array(era_h5, name=name, obj=obj)
