@@ -21,14 +21,14 @@ def __zeros__(shape, dtype, max_mem_frac=0.3, logger=None):
 
     # noinspection PyShadowingNames
     def out_memory_array(shape, dtype):
-        logger.warning("Not enough memory to keep full image -> fall back to memorymap.")
+        logger.warning("Not enough memory to keep full image -> fall back to memory map.")
         dat = np.memmap(filename=TemporaryFile(mode="w+b"), dtype=dtype, shape=tuple(shape))
         dat[:] = 0.0
         return dat
 
     to_gb = 1.0 / 1024.0 ** 3
     mem = virtual_memory().total * to_gb
-    arr = np.int(np.prod(np.array(shape, dtype=np.int64)) * np.zeros(1, dtype=dtype).nbytes * to_gb)
+    arr = int(np.prod(np.array(shape, dtype=np.int64)) * np.zeros(1, dtype=dtype).nbytes * to_gb)
 
     if arr < max_mem_frac * mem:
         try:
@@ -37,7 +37,7 @@ def __zeros__(shape, dtype, max_mem_frac=0.3, logger=None):
             return out_memory_array(shape, dtype)
     else:
         logger.info(
-            "Try to create array of size %.2fGB on a box with %.2fGB memory -> fall back to memorymap." % (
+            "Try to create array of size %.2fGB on a box with %.2fGB memory -> fall back to memory map." % (
                 arr, mem))
         return out_memory_array(shape, dtype)
 
@@ -62,7 +62,7 @@ def save_divide(d1, d2, mx=100.0):
     """ save division without introducing NaN's
     :param d1:
     :param d2:
-    :param mx: absolute maximum allows value which from which on the result is chopped
+    :param mx: absolute maximum allows value from which on the result is chopped
     :return: d1/d2
     """
     dd1 = to_clf(d1)
@@ -78,9 +78,9 @@ def save_divide(d1, d2, mx=100.0):
 def to_clf(inp):
     """ helper function which sets the type of features and assures numeric values
     :param inp:
-    :return: np.float array without NaN's or INF's
+    :return: float array without NaN's or INF's
     """
-    return np.nan_to_num(np.array(inp, dtype=np.float))
+    return np.nan_to_num(np.array(inp, dtype=float))
 
 
 class _ToClassifierBase(object):
@@ -100,7 +100,7 @@ class _ToClassifierBase(object):
         self.classifiers_id_full = None
 
     def adjust_classifier_ids(self, full_bands, band_lists):
-        self.classifiers_id = [np.array([band_lists.index(full_bands[ii]) for ii in clf], dtype=np.int)
+        self.classifiers_id = [np.array([band_lists.index(full_bands[ii]) for ii in clf], dtype=int)
                                for clf in self.classifiers_id_full]
         self.logger.info("""Adjusting classifier channel list indices to actual image, convert from:
 %s to \n %s. \n This results in a changed classifier index array from:""" % (str(full_bands), str(band_lists)))
@@ -278,20 +278,20 @@ def __test__(clf, xx, yy, sample_weight=None, norm="right_class"):
 
     if norm == "right_class":
         if sample_weight is None:
-            return np.sum(clf.predict(xx) == yy) / np.float(len(yy))  # ratio of correct
+            return np.sum(clf.predict(xx) == yy) / float(len(yy))  # ratio of correct
         else:
-            yy = np.array(clf.predict(xx) == yy, dtype=np.int)
+            yy = np.array(clf.predict(xx) == yy, dtype=int)
             yy[yy == 1] = 1
             yy[yy == 0] = -1
             return np.sum(yy * sample_weight)
 
     elif norm == "class_distance":
         if sample_weight is None:
-            return 1.0 - np.sum(np.abs(np.array(clf.predict(xx) - yy, dtype=np.float))) / np.float(
+            return 1.0 - np.sum(np.abs(np.array(clf.predict(xx) - yy, dtype=float))) / float(
                 len(yy) * clf.n_classes)
         else:
             return 1.0 - np.sum(sample_weight *
-                                np.abs(np.array(clf.predict(xx) - yy, dtype=np.float))) / np.float(
+                                np.abs(np.array(clf.predict(xx) - yy, dtype=float))) / float(
                 len(yy) * clf.n_classes)
 
     elif norm == "scatter":
@@ -329,12 +329,12 @@ def histogramdd_fast(data, bins):
     n_clf = len(bins)
     n_bins = len(bins[0])
 
-    assigns = np.zeros(n_smpl, dtype=np.int)
+    assigns = np.zeros(n_smpl, dtype=int)
     for ii, bb in enumerate(bins):
         assigns += digitize(data[:, ii], bb[1:-1]) * n_bins ** ii
 
     bc = np.bincount(assigns, minlength=n_bins ** n_clf).reshape(n_clf * [n_bins]).T
-    return np.array(bc, dtype=np.float) / n_smpl
+    return np.array(bc, dtype=float) / n_smpl
 
 
 class ClassicalBayesian(object):
@@ -379,7 +379,7 @@ class ClassicalBayesian(object):
         tt = 0
         for ii in ids:
             self.__in_bounds__(ii)
-        pp = np.zeros((self.n_classes, len(ids[0])), dtype=np.float)
+        pp = np.zeros((self.n_classes, len(ids[0])), dtype=float)
         for ii, cl in enumerate(self.classes):
             hh = self.hh[cl][tuple(ids)]
             hh_full = self.hh_full[tuple(ids)]
@@ -409,7 +409,7 @@ class ClassicalBayesian(object):
                         self.ar_hh[cl][iw] = gaussian_filter(zoom(ar_hh, order=1, zoom=self.zm), self.gs)
                         ar_hh = self.ar_hh[cl][iw]
                     n_bins = ar_hh_full.shape[0]
-                    ids_bf = [np.array(id_bf[hh_invalid] * (n_bins / self.n_bins), dtype=np.int) for id_bf in ids]
+                    ids_bf = [np.array(id_bf[hh_invalid] * (n_bins / self.n_bins), dtype=int) for id_bf in ids]
                     for ii_bf in ids_bf:
                         ii_bf[ii_bf > n_bins - 1] = n_bins
 
@@ -425,7 +425,7 @@ class ClassicalBayesian(object):
                     self.logger.info("class: %s, bins: %i->%i,curr ok: %i, still bad: %i" %
                                      (str(cl), self.n_bins, n_bins, int(np.sum(hh_ok)), int(np.sum(hh_invalid))))
             tt += time() - t0
-        self.logger.info("Time spent in reduced form: %.2fs" % tt)
+        self.logger.info("Time spent in reduced form: %.2f" % tt)
         return pp
 
     def predict_proba(self, xx):
@@ -458,7 +458,7 @@ class ClassicalBayesian(object):
 class ClassicalBayesianFit(ClassicalBayesian):
     def __init__(self, mk_clf, smooth_min=0.0, smooth_max=2.0, n_bins_min=5, n_bins_max=20, n_runs=10000, smooth_dd=10,
                  max_mb=100.0, norm="right_class", ff=None, xx=None, yy=None, max_run_time=60,
-                 sample_weight=None, use_tqdm=False, sufficient_norm=None, dtype=np.float,
+                 sample_weight=None, use_tqdm=False, sufficient_norm=None, dtype=float,
                  fit_method="random", smooth=None, logger=None):
         """
         ff: function of two variables, combines ff_train,ff_test -> ff which is maximised during fit, default
@@ -506,7 +506,7 @@ class ClassicalBayesianFit(ClassicalBayesian):
 
             self.n_bins_min = n_bins_min
             self.n_bins_max = np.min([
-                n_bins_max, np.int(np.floor((max_mb / (np.zeros(1, dtype=self.dtype).nbytes / 1024. ** 2)) ** (
+                n_bins_max, int(np.floor((max_mb / (np.zeros(1, dtype=self.dtype).nbytes / 1024. ** 2)) ** (
                     1.0 / self.mk_clf.n_classifiers)))])
             assert self.n_bins_max >= self.n_bins_min
 
@@ -516,8 +516,8 @@ class ClassicalBayesianFit(ClassicalBayesian):
 
             self.n_bins = None
             self.smooth_values = list(np.around(
-                np.linspace(smooth_min, smooth_max, np.int(smooth_dd)),
-                decimals=np.int(np.ceil(-1 * np.log10((smooth_max - smooth_min) / smooth_dd)))))
+                np.linspace(smooth_min, smooth_max, int(smooth_dd)),
+                decimals=int(np.ceil(-1 * np.log10((smooth_max - smooth_min) / smooth_dd)))))
 
             self.params.update({"smooth_min": smooth_min,
                                 "smooth_max": smooth_max,
@@ -534,7 +534,7 @@ class ClassicalBayesianFit(ClassicalBayesian):
 
             if xx is not None and yy is not None:
                 if type(smooth) is dict:
-                    n_bins = np.int(self.n_bins_min + np.random.sample() * (self.n_bins_max - self.n_bins_min))
+                    n_bins = int(self.n_bins_min + np.random.sample() * (self.n_bins_max - self.n_bins_min))
                     self.set(xx=xx, yy=yy, sample_weight=sample_weight, n_bins=n_bins, smooth=smooth)
                 else:
                     self.fit(xx=xx, yy=yy, sample_weight=sample_weight, sufficient_norm=sufficient_norm)
